@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
 #
-# pymsn - a python client library for Msn
-#
 # Copyright (C) 2005-2006 Ali Sabil <ali.sabil@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -22,14 +20,22 @@
 
 pymsn is a library, written in Python, for accessing the MSN
 instant messaging service.
+    
+    @group High Level Interface: client, profile, conversation, event
+    @group Low Level Interface: msnp, msnp2p, service
+    @group Network Layer: gnet
 """
 
-__version__ = "$Id$"
+__version__ = "0.3.3"
+__author__ = "Ali Sabil <ali.sabil@gmail.com>"
+__url__ = "http://telepathy.freedesktop.org/wiki/Pymsn"
+__license__ = "GNU GPL"
 
-from consts import ContactListStatus, PresenceStatus, MessageAcknowledgement, \
-    List
-from protocol import Contact
-from gio import network
-from client import Client, Conversation
-import transport
-import storage
+from client import *
+from conversation import *
+from profile import NetworkID, Presence, Privacy, Membership, Contact, Group
+import event
+
+import gnet.proxy
+Proxy = gnet.proxy.ProxyFactory
+ProxyInfos = gnet.proxy.ProxyInfos
